#ifndef NT2_INCLUDE_FUNCTIONS_IS_LESS_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_LESS_EQUAL_HPP_INCLUDED

#include <nt2/operator/include/functions/is_less_equal.hpp>

#endif
